@@ -23,8 +23,13 @@ sub result_verifiers {
 
 __PACKAGE__->load_components(qw(
    Helper::Schema::Verifier
+   Helper::Schema::Verifier::Parent
 ));
 
+# so ::Verifier::load_classes gets tested too
+__PACKAGE__->load_classes({
+   ParentSchema => [qw/ Result::Foo Result::Bar /],
+});
 __PACKAGE__->load_namespaces;
 
 'zomg';
